pub struct NodeClosure<T: Transcendental, const BUF_SIZE: usize> { /* private fields */ }Expand description
One compiled graph node — owns its algorithm and buffer routing.
Implementations
Sourceimpl<T: Transcendental, const BUF_SIZE: usize> NodeClosure<T, BUF_SIZE>
impl<T: Transcendental, const BUF_SIZE: usize> NodeClosure<T, BUF_SIZE>
Sourcepub fn execute(
&mut self,
buffers: &mut [FixedBuffer<T, BUF_SIZE>],
) -> ProcessResult<()>
pub fn execute( &mut self, buffers: &mut [FixedBuffer<T, BUF_SIZE>], ) -> ProcessResult<()>
Execute this node’s algorithm, reading from and writing to the buffer pool.
Sourcepub fn set_param(&mut self, index: usize, value: &ParamValue)
pub fn set_param(&mut self, index: usize, value: &ParamValue)
Set a parameter by index on the owned algorithm.