Instr

Enum Instr 

pub enum Instr {
    Const {
        dst: Reg,
        value: f64,
    },
    LoadInput {
        dst: Reg,
        index: usize,
    },
    ReadState {
        dst: Reg,
        slot: StateSlot,
    },
    ReadDelay {
        dst: Reg,
        line: usize,
    },
    Un {
        dst: Reg,
        op: UnOp,
        src: Reg,
    },
    Bin {
        dst: Reg,
        op: BinArith,
        a: Reg,
        b: Reg,
    },
    Move {
        dst: Reg,
        src: Reg,
    },
    WriteState {
        slot: StateSlot,
        src: Reg,
    },
    WriteDelay {
        line: usize,
        src: Reg,
    },
    CallSample {
        dst: Reg,
        srcs: Vec<Reg>,
        instance: usize,
    },
    CallBlock {
        dst: Reg,
        src: Reg,
        instance: usize,
    },
    ReadParam {
        dst: Reg,
        idx: usize,
    },
}
One IR instruction. dst is the scratch register it writes.

Variants



Const

Load a constant.

Fields

dst: Reg

Destination register.

value: f64

Constant value to load.



LoadInput

Load the k-th program input for the current sample.

Fields

dst: Reg

Destination register.

index: usize

Program input index.



ReadState

Read a persistent state slot (its value from the previous sample).

Fields

dst: Reg

Destination register.

slot: StateSlot

State slot to read.



ReadDelay

Read from a delay line: value len samples ago.

Fields

dst: Reg

Destination register.

line: usize

Delay line index.



Un

Unary op.

Fields

dst: Reg

Destination register.

op: UnOp

Unary operation.

src: Reg

Source register.



Bin

Binary op.

Fields

dst: Reg

Destination register.

op: BinArith

Binary operation.

a: Reg

First operand register.

b: Reg

Second operand register.



Move

Copy one register to another (wire).

Fields

dst: Reg

Destination register.

src: Reg

Source register.



WriteState

Schedule a write of src into state slot at end of the sample.

Fields

slot: StateSlot

State slot to write.

src: Reg

Source register.



WriteDelay

Schedule a push of src into a delay line at end of the sample.

Fields

line: usize

Delay line index.

src: Reg

Source register.



CallSample

Call a per-sample built-in: srcs inputs → dst, instance index.

Fields

dst: Reg

Destination register.

srcs: Vec<Reg>

Source registers.

instance: usize

Index into Ir::builtins.



CallBlock

Call a whole-buffer built-in (1→1): srcdst, instance index.

Fields

dst: Reg

Destination register.

src: Reg

Source register.

instance: usize

Index into Ir::builtins.



ReadParam

Read a named parameter slot. Value is constant within a block.

Fields

dst: Reg

Destination register.

idx: usize

Index into Ir::params.